"use strict";(self.webpackChunk_infuseai_piperider_ui=self.webpackChunk_infuseai_piperider_ui||[]).push([[836],{6836:function(e,t,n){n.r(t),n.d(t,{default:function(){return _}});var r=n(9439),i=n(4190),a=n(7094),s=n(8625),l=n(2791),o=n(8353),c=n(8693),d=n(5650),u=n(1573),x=n(8982),m=n(2104),h=n(709),p=n(1892),j=n(8493),b=n(4304),f=n(4494),g=n(4387),w=n(5460),v=n(1364),C=n(184);function _(e){var t=e.data,n=t.tables,_=t.created_at,R=e.columnName,S=e.tableName,P=(0,s.TH)(),D=(0,r.Z)(P,2)[1],y=(0,l.useState)(0),T=(0,r.Z)(y,2),H=T[0],O=T[1],k=(0,h.D8)(_)||"",N=decodeURIComponent(R),I=decodeURIComponent(S),Q=0===N.length,A=n[I],K=A.columns[N],M=K||{},Y=M.type,E=M.histogram,U=(0,b.MM)(K),W=U.backgroundColor,Z=U.icon;if(!S||!A)return(0,C.jsx)(o.o,{isSingleReport:!0,time:k,children:(0,C.jsx)(j.J,{text:"No profile data found for table name: ".concat(S)})});var z=[{label:"Tables",path:"/"},{label:I,path:"/tables/".concat(I,"/columns/")},{label:N,path:"/tables/".concat(I,"/columns/").concat(N)}];return(0,C.jsx)(o.o,{isSingleReport:!0,time:k,maxHeight:u.t4,children:(0,C.jsxs)(i.rj,{width:"inherit",templateColumns:"1fr 2fr",children:[(0,C.jsx)(i.P4,{colSpan:3,children:(0,C.jsx)(w.Qu,{breadcrumbList:z})}),(0,C.jsx)(i.P4,{overflowY:"scroll",maxHeight:u.t4,children:(0,C.jsx)(m._,{baseDataTables:n,currentTable:I,currentColumn:N,onSelect:function(e){var t=e.tableName,n=e.columnName;O(0),D("/tables/".concat(t,"/columns/").concat(n))},singleOnly:!0})}),Q?(0,C.jsxs)(i.P4,{maxHeight:u.t4,overflowY:"auto",p:10,children:[(0,C.jsx)(v.Q,{title:A.name,subtitle:"Table",mb:5}),(0,C.jsxs)(a.mQ,{defaultIndex:0,children:[(0,C.jsxs)(a.td,{children:[(0,C.jsx)(a.OK,{children:"Overview"}),(0,C.jsx)(a.OK,{children:"Assertions"}),(0,C.jsx)(a.OK,{children:"Schema"})]}),(0,C.jsxs)(a.nP,{children:[(0,C.jsx)(a.x4,{children:(0,C.jsxs)(i.rj,{templateColumns:"1fr 1px 1fr",gap:3,children:[(0,C.jsx)(f.m,{tableDatum:A}),(0,C.jsx)(i.iz,{orientation:"vertical"}),(0,C.jsx)(f.a,{description:A.description})]})}),(0,C.jsx)(a.x4,{children:(0,C.jsx)(g.E,{assertions:{piperider:A.piperider_assertion_result,dbt:null===A||void 0===A?void 0:A.dbt_assertion_result}})}),(0,C.jsx)(a.x4,{children:(0,C.jsx)(w.rH,{baseTableDatum:A,singleOnly:!0,onSelect:function(){}})})]})]})]}):(0,C.jsxs)(i.rj,{templateColumns:"500px 1fr",templateRows:"7em 1fr 1fr",width:"100%",maxHeight:u.t4,overflowY:"auto",children:[(0,C.jsx)(i.P4,{colSpan:2,rowSpan:1,p:9,children:(0,C.jsx)(v.Q,{title:R,subtitle:"Column",p:2,borderBottom:u.dx,icon:Z,iconColor:W})}),(0,C.jsx)(i.P4,{p:10,bg:"gray.50",borderRight:u.dx,children:(0,C.jsx)(c.t,{columnDatum:K,hasAnimation:!0})}),(0,C.jsx)(i.P4,{gridRow:"span 1",minWidth:0,p:9,bg:"gray.50",children:(0,C.jsx)(d.r,{baseColumnDatum:K,hasAnimation:!0,tabIndex:H,onSelectTab:function(e){return O(e)}})}),(0,C.jsx)(i.P4,{gridRow:"span 1",p:9,bg:"gray.50",borderRight:u.dx,children:(0,b.jl)(Y)&&(0,C.jsx)(C.Fragment,{children:(0,C.jsx)(p.E,{columnDatum:K})})}),(0,b.hG)(Y)&&E&&(0,C.jsx)(i.P4,{gridRow:"span 1",p:9,bg:"gray.50",minWidth:"1px",children:(0,C.jsx)(x.M,{columnDatum:K})})]})]})})}}}]);
//# sourceMappingURL=836.7fd48331.chunk.js.map